@@ -42,6 +42,7 @@
 #include "MapGenerator.h"
 #include "QuestsManager.h"
 #include "Configuration.h"
+#include "FogMap.h"
 
 using namespace std;
 
@@ -54,8 +55,8 @@ CreateScenario::CreateScenario()
     debug("CreateScenario::CreateScenario")
    
    //default value
-    setWidth(100);
-    setHeight(100);
+    setWidth(112);
+    setHeight(156);
     
     //make sure that objects are deleted
     GameMap::deleteInstance();
@@ -317,19 +318,37 @@ std::string CreateScenario::getMapTiles() const
     return d_tilesname;
 }
 
-bool CreateScenario::create()
+bool CreateScenario::create(const GameParameters &g)
 {
     debug("CreateScenario::create")
 
     d_scenario = new GameScenario("AutoGenerated", "AutoGenerated", d_turnmode);
 
+    GameScenario::s_see_opponents_stacks = g.see_opponents_stacks;
+    GameScenario::s_see_opponents_production = g.see_opponents_production;
+    GameScenario::s_play_with_quests = g.play_with_quests;
+    GameScenario::s_hidden_map = g.hidden_map;
+    GameScenario::s_diplomacy = g.diplomacy;
+    GameScenario::s_neutral_cities = g.neutral_cities;
+    GameScenario::s_military_advisor= g.military_advisor;
+    GameScenario::s_random_turns = g.random_turns;
+    GameScenario::s_intense_combat = g.intense_combat;
+
     if (!createMap())
         return false;
 
+    // fog it up
+    if (GameScenario::s_hidden_map)
+      {
+        Playerlist::iterator pit = Playerlist::getInstance()->begin();
+        for (; pit != Playerlist::getInstance()->end(); pit++)
+          (*pit)->getFogMap()->fill(FogMap::CLOSED);
+      }
+
     if (!distributePlayers())
         return false;
 
-    if (!setupCities())
+    if (!setupCities(g.quick_start))
         return false;
 
     if (!setupTemples())
@@ -433,7 +452,7 @@ bool CreateScenario::distributePlayers()
         if ((skipping >= cityskip) && (pit != pl->end()))
         {
             // distribute capitals for the players
-            (*cit).setPlayer(*pit);
+            (*cit).conquer(*pit);
             (*cit).setCapitalOwner(*pit);
             (*cit).setCapital(true);
             skipping = 0;
@@ -449,10 +468,42 @@ bool CreateScenario::distributePlayers()
     return true;
 }
 
-bool CreateScenario::setupCities()
+bool CreateScenario::setupCities(bool quick_start)
 {
     debug("CreateScenario::setupCities")
 
+    if (quick_start)
+      {
+        Playerlist *plist = Playerlist::getInstance();
+        Citylist *clist = Citylist::getInstance();
+        Vector <int> pos;
+        // no neutral cities
+        // divvy up the neutral cities among other non-neutral players
+        int cities_left = clist->size() - plist->size() + 1;
+        int citycount[MAX_PLAYERS];
+	memset (citycount, 0, sizeof (citycount));
+        Playerlist::iterator pit = plist->begin();
+        for (; pit != plist->end(); pit++)
+          {
+            if (*pit == plist->getNeutral())
+              pit = plist->begin();
+            citycount[(*pit)->getId()]++;
+            cities_left--;
+            if (cities_left == 0)
+              break;
+          }
+        for (unsigned int i = 0; i < MAX_PLAYERS; i++)
+          {
+            for (unsigned int j = 0; j < citycount[i]; j++)
+              {
+                Player *p = plist->getPlayer(i);
+                pos = clist->getFirstCity(p)->getPos();
+	        City *c = clist->getNearestNeutralCity(pos);
+                c->conquer(p);
+              }
+          }
+      }
+
     for (Citylist::iterator it = Citylist::getInstance()->begin();
         it != Citylist::getInstance()->end(); it++)
     {
@@ -468,14 +519,32 @@ bool CreateScenario::setupCities()
 
         //3. set the city production
         (*it).setRandomArmytypes();
-        if ((*it).isCapital())
-          (*it).produceStrongestArmy();
-        else
-          (*it).produceWeakestArmy();
         if ((*it).getPlayer() == Playerlist::getInstance()->getNeutral())
+        {
+            switch (GameScenario::s_neutral_cities)
+              {
+              case GameParameters::AVERAGE:
+                (*it).produceWeakestArmy();
+                break;
+              case GameParameters::STRONG:
+                (*it).produceStrongestArmy();
+                break;
+              case GameParameters::ACTIVE:
+                if (rand () % 100 >  20)
+                  (*it).produceStrongestArmy();
+                else
+                  (*it).produceWeakestArmy();
+                break;
+              }
             (*it).setProduction(-1);
+        }
         else
         {
+          if ((*it).isCapital())
+            (*it).produceStrongestArmy();
+          else
+            (*it).produceWeakestArmy();
+
             (*it).setProduction(0);
             //raise the city defense to the highest level
             for (; (*it).raiseDefense(););
