@@ -18,6 +18,7 @@
 #include <string>
 #include <list>
 #include <sigc++/trackable.h>
+#include "game-parameters.h"
 
 class XML_Helper;
 
@@ -81,6 +82,16 @@ class GameScenario: public sigc::trackable
           * @return true if all went well, false otherwise
           */
         bool saveGame(std::string filename, std::string extension = "sav") const;
+        static bool s_see_opponents_stacks;
+        static bool s_see_opponents_production;
+        static bool s_play_with_quests;
+        static bool s_hidden_map;
+        static bool s_diplomacy;
+        static GameParameters::NeutralCities s_neutral_cities;
+        static bool s_intense_combat;
+        static bool s_military_advisor;
+        static bool s_random_turns;
+
     private:
         /** Callback function for loading a game. See XML_Helper for details.
           *
