@@ -15,7 +15,9 @@
 #include "Location.h"
 #include "army.h"
 #include "player.h"
+#include "playerlist.h"
 #include "stacklist.h"
+#include "FogMap.h"
 
 #include "xmlhelper.h"
 
@@ -76,3 +78,35 @@ Stack* Location::getFreeStack(Player *p) const
     return NULL;
 }
 
+bool Location::isFogged()
+{
+  FogMap *fogmap = Playerlist::getActiveplayer()->getFogMap();
+  for (unsigned int i = 0; i < d_size; i++)
+    for (unsigned int j = 0; j < d_size; j++)
+      {
+        Vector<int> pos;
+        pos.x = d_pos.x + i;
+        pos.y = d_pos.y + j;
+        if (fogmap->getFogTile(pos) == FogMap::CLOSED)
+          return true;
+      }
+  return false;
+}
+
+void Location::deFog()
+{
+  Player *p = Playerlist::getActiveplayer();
+  if (!p)
+    return;
+  FogMap *fogmap = p->getFogMap();
+  fogmap->alterFogRadius (d_pos, 3, FogMap::OPEN);
+}
+void Location::deFog(Player *p)
+{
+  if (!p)
+    return;
+  FogMap *fogmap = p->getFogMap();
+  if (!fogmap)
+    return;
+  fogmap->alterFogRadius (d_pos, 3, FogMap::OPEN);
+}
