@@ -21,6 +21,7 @@
 #include "armysetlist.h"
 #include "hero.h"
 #include "vectoredunitlist.h"
+#include "FogMap.h"
 
 #include "path.h"
 
@@ -126,6 +127,7 @@ void NextTurn::finishTurn()
 {
     //Put everything that has to be done before the next player starts
     //his turn here. E.g. one could clear some caches.
+    Playerlist::getActiveplayer()->getFogMap()->smooth();
 }
 
 void NextTurn::finishRound()
