@@ -20,6 +20,7 @@
 #include "stack.h"
 #include "army.h"
 #include "city.h"
+#include "signpost.h"
 #include "ruin.h"
 #include "temple.h"
 #include "Quest.h"
@@ -30,6 +31,8 @@
 #include "QCityRaze.h"
 #include "QCityOccupy.h"
 #include "QPillageGold.h"
+#include "armysetlist.h"
+#include "playerlist.h"
 
 using namespace std;
 
@@ -86,6 +89,18 @@ Action* Action::handle_load(XML_Helper* helper)
             return (new Action_Equip(helper));
         case UNIT_ADVANCE:
             return (new Action_Level(helper));
+        case STACK_DISBAND:
+            return (new Action_Disband(helper));
+        case MODIFY_SIGNPOST:
+            return (new Action_ModifySignpost(helper));
+        case CITY_RENAME:
+            return (new Action_RenameCity(helper));
+        case CITY_VECTOR:
+            return (new Action_Vector(helper));
+        case FIGHT_ORDER:
+            return (new Action_FightOrder(helper));
+        case RESIGN:
+            return (new Action_Resign(helper));
     }
 
     return 0;
@@ -129,6 +144,18 @@ Action* Action::copy(const Action* a)
             return (new Action_Equip(*dynamic_cast<const Action_Equip*>(a)));
         case UNIT_ADVANCE:
             return (new Action_Level(*dynamic_cast<const Action_Level*>(a)));
+        case STACK_DISBAND:
+            return (new Action_Disband(*dynamic_cast<const Action_Disband*>(a)));
+        case MODIFY_SIGNPOST:
+            return (new Action_ModifySignpost(*dynamic_cast<const Action_ModifySignpost*>(a)));
+        case CITY_RENAME:
+            return (new Action_RenameCity(*dynamic_cast<const Action_RenameCity*>(a)));
+        case CITY_VECTOR:
+            return (new Action_Vector(*dynamic_cast<const Action_Vector*>(a)));
+        case FIGHT_ORDER:
+            return (new Action_FightOrder(*dynamic_cast<const Action_FightOrder*>(a)));
+        case RESIGN:
+            return (new Action_Resign(*dynamic_cast<const Action_Resign*>(a)));
     }
 
     return 0;
@@ -1112,3 +1139,306 @@ bool Action_Level::fillData(Uint32 unit, Army::Stat raised)
     return true;
 }
 
+//-----------------------------------------------------------------------------
+//Action_Disband
+
+Action_Disband::Action_Disband()
+    :Action(Action::STACK_DISBAND), d_stack(0)
+{
+}
+
+Action_Disband::Action_Disband(XML_Helper* helper)
+    :Action(Action::STACK_DISBAND)
+{
+    helper->getData(d_stack, "stack");
+}
+
+Action_Disband::~Action_Disband()
+{
+}
+
+std::string Action_Disband::dump() const
+{
+    std::stringstream s;
+
+    s <<"Stack " <<d_stack <<" disbanded\n";
+    
+    return s.str();
+}
+
+bool Action_Disband::save(XML_Helper* helper) const
+{
+    bool retval = true;
+
+    retval &= helper->openTag("action");
+    retval &= helper->saveData("type", d_type);
+    retval &= helper->saveData("stack", d_stack);
+    retval &= helper->closeTag();
+
+    return retval;
+}
+
+bool Action_Disband::fillData(Stack* s)
+{
+    d_stack = s->getId();
+    return true;
+}
+
+//-----------------------------------------------------------------------------
+//Action_ModifySignpost
+
+Action_ModifySignpost::Action_ModifySignpost()
+    :Action(Action::MODIFY_SIGNPOST), d_signpost(0), d_message("")
+{
+}
+
+Action_ModifySignpost::Action_ModifySignpost(XML_Helper* helper)
+    :Action(Action::MODIFY_SIGNPOST)
+{
+    helper->getData(d_signpost, "signpost");
+    helper->getData(d_message, "message");
+}
+
+Action_ModifySignpost::~Action_ModifySignpost()
+{
+}
+
+std::string Action_ModifySignpost::dump() const
+{
+    std::stringstream s;
+
+    s <<"Signpost " <<d_signpost <<" modified to read" << d_message <<".\n";
+    
+    return s.str();
+}
+
+bool Action_ModifySignpost::save(XML_Helper* helper) const
+{
+    bool retval = true;
+
+    retval &= helper->openTag("action");
+    retval &= helper->saveData("type", d_type);
+    retval &= helper->saveData("signpost", d_signpost);
+    retval &= helper->saveData("message", d_message);
+    retval &= helper->closeTag();
+
+    return retval;
+}
+
+bool Action_ModifySignpost::fillData(Signpost * s, std::string message)
+{
+    d_signpost = s->getId();
+    d_message = message; 
+    return true;
+}
+
+//-----------------------------------------------------------------------------
+//Action_RenameCity
+
+Action_RenameCity::Action_RenameCity()
+    :Action(Action::CITY_RENAME), d_city(0), d_name("")
+{
+}
+
+Action_RenameCity::Action_RenameCity(XML_Helper* helper)
+    :Action(Action::CITY_RENAME)
+{
+    helper->getData(d_city, "city");
+    helper->getData(d_name, "name");
+}
+
+Action_RenameCity::~Action_RenameCity()
+{
+}
+
+std::string Action_RenameCity::dump() const
+{
+    std::stringstream s;
+
+    s <<"City " <<d_city <<" renamed to " << d_name<<".\n";
+    
+    return s.str();
+}
+
+bool Action_RenameCity::save(XML_Helper* helper) const
+{
+    bool retval = true;
+
+    retval &= helper->openTag("action");
+    retval &= helper->saveData("type", d_type);
+    retval &= helper->saveData("city", d_city);
+    retval &= helper->saveData("name", d_name);
+    retval &= helper->closeTag();
+
+    return retval;
+}
+
+bool Action_RenameCity::fillData(City* c, std::string name)
+{
+    d_city = c->getId();
+    d_name = name; 
+    return true;
+}
+
+//-----------------------------------------------------------------------------
+//Action_Vector
+
+Action_Vector::Action_Vector()
+    :Action(Action::CITY_VECTOR)
+{
+}
+
+Action_Vector::Action_Vector(XML_Helper* helper)
+    :Action(Action::CITY_VECTOR)
+{
+    helper->getData(d_city, "city");
+    int i;
+    helper->getData(i, "x");
+    d_dest.x = i;
+    helper->getData(i, "y");
+    d_dest.y = i;
+}
+
+Action_Vector::~Action_Vector()
+{
+}
+
+std::string Action_Vector::dump() const
+{
+    std::stringstream s;
+
+    s <<"Vectoring new units from city " <<d_city <<" to ";
+    s <<d_dest.x <<"," <<d_dest.y <<")\n";
+    
+    return s.str();
+}
+
+bool Action_Vector::save(XML_Helper* helper) const
+{
+    bool retval = true;
+
+    retval &= helper->openTag("action");
+    retval &= helper->saveData("type", d_type);
+    retval &= helper->saveData("city", d_city);
+    retval &= helper->saveData("x", d_dest.x);
+    retval &= helper->saveData("y", d_dest.y);
+    retval &= helper->closeTag();
+
+    return retval;
+}
+
+bool Action_Vector::fillData(City* src, Vector <int> dest)
+{
+    d_city = src->getId();
+    d_dest = dest;
+    return true;
+}
+
+//-----------------------------------------------------------------------------
+//Action_FightOrder
+
+Action_FightOrder::Action_FightOrder()
+    :Action(Action::FIGHT_ORDER)
+{
+}
+
+Action_FightOrder::Action_FightOrder(XML_Helper* helper)
+    :Action(Action::FIGHT_ORDER)
+{
+    std::string fight_order;
+    std::stringstream sfight_order;
+    Uint32 val;
+    helper->getData(fight_order, "order");
+    sfight_order.str(fight_order);
+    Uint32 size = Armysetlist::getInstance()->getSize(Playerlist::getInstance()->getFirstLiving()->getArmyset());
+    for (unsigned int i = 0; i < size; i++)
+    {
+            sfight_order >> val;
+            d_order.push_back(val);
+    }
+}
+
+Action_FightOrder::~Action_FightOrder()
+{
+}
+
+std::string Action_FightOrder::dump() const
+{
+    std::stringstream s;
+
+    s <<"changed fight order to:" ;
+    std::list<Uint32>::const_iterator it = d_order.begin();
+    for ( ;it != d_order.end(); it++)
+      {
+        s <<" " << (*it);
+      }
+      s << "\n";
+    
+    return s.str();
+}
+
+bool Action_FightOrder::save(XML_Helper* helper) const
+{
+    bool retval = true;
+
+    retval &= helper->openTag("action");
+    retval &= helper->saveData("type", d_type);
+    std::stringstream fight_order;
+    for (std::list<Uint32>::const_iterator it = d_order.begin();
+         it != d_order.end(); it++)
+      {
+        fight_order << (*it) << " ";
+      }
+    retval &= helper->saveData("order", fight_order.str());
+    retval &= helper->closeTag();
+
+    return retval;
+}
+
+bool Action_FightOrder::fillData(std::list<Uint32> order)
+{
+    d_order = order;
+    return true;
+}
+
+//-----------------------------------------------------------------------------
+//Action_Resign
+
+Action_Resign::Action_Resign()
+    :Action(Action::RESIGN)
+{
+}
+
+Action_Resign::Action_Resign(XML_Helper* helper)
+    :Action(Action::RESIGN)
+{
+}
+
+Action_Resign::~Action_Resign()
+{
+}
+
+std::string Action_Resign::dump() const
+{
+    std::stringstream s;
+    s << "this player resigns\n";
+    
+    return s.str();
+}
+
+bool Action_Resign::save(XML_Helper* helper) const
+{
+    bool retval = true;
+
+    retval &= helper->openTag("action");
+    retval &= helper->saveData("type", d_type);
+    retval &= helper->closeTag();
+
+    return retval;
+}
+
+bool Action_Resign::fillData()
+{
+    return true;
+}
+
