@@ -39,6 +39,7 @@
 #include "citylist.h"
 #include "ruinlist.h"
 #include "templelist.h"
+#include "signpostlist.h"
 #include "armysetlist.h"
 #include "city.h"
 #include "ruin.h"
@@ -51,6 +52,8 @@
 #include "File.h"
 #include "Quest.h"
 #include "reward.h"
+#include "game-parameters.h"
+#include "FogMap.h"
 
 
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<flush<<endl;}
@@ -119,7 +122,7 @@ Game::Game(GameScenario* gameScenario)
 	
         p->sinvadingCity.connect(sigc::mem_fun(this, &Game::invading_city));
         p->fight_started.connect(
-	    sigc::mem_fun(fight_started, &sigc::signal<void, Fight &>::emit));
+	    sigc::mem_fun(*this, &Game::on_fight_started));
         p->ruinfight_started.connect(
 	    sigc::mem_fun(ruinfight_started, &sigc::signal<void, Stack *, Stack *>::emit));
         p->ruinfight_finished.connect(
@@ -161,6 +164,10 @@ void Game::end_turn()
 void Game::update_stack_info()
 {
     Stack* stack = Playerlist::getActiveplayer()->getActivestack();
+
+    if (Playerlist::getActiveplayer()->getType() != Player::HUMAN &&
+        GameScenario::s_hidden_map == true)
+      return;
     stack_info_changed.emit(stack);
 }
 
@@ -593,9 +600,12 @@ void Game::update_control_panel()
 	can_center_selected_stack.emit(false);
 	can_defend_selected_stack.emit(false);
 	can_search_selected_stack.emit(false);
+	can_inspect_selected_stack.emit(false);
 	can_move_selected_stack.emit(false);
 	can_move_all_stacks.emit(false);
 	can_end_turn.emit(false);
+	can_disband_stack.emit(false);
+	can_change_signpost.emit(false);
 	
         return;
     }
@@ -654,11 +664,21 @@ void Game::update_control_panel()
 	        can_search_selected_stack.emit(temple);
             }
         }
+
+        if (stack->hasHero())
+          can_inspect_selected_stack.emit(true);
+
+        if (Signpostlist::getInstance()->getObjectAt(stack->getPos()))
+          can_change_signpost.emit(true);
+
+        can_disband_stack.emit(true);
     }
     else
     {
 	can_search_selected_stack.emit(false);
 	can_move_selected_stack.emit(false);
+	can_disband_stack.emit(false);
+	can_inspect_selected_stack.emit(false);
     }
 
     can_end_turn.emit(true);
@@ -678,6 +698,7 @@ SmallMap &Game::get_smallmap()
 
 void Game::startGame()
 {
+
     debug ("start_game()");
     lock_inputs();
 
@@ -944,6 +965,14 @@ void Game::on_player_died(Player *player)
 	player_died.emit(player);
 }
 
+void Game::on_fight_started(Fight &fight)
+{
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN &&
+      GameScenario::s_hidden_map == true)
+    return;
+  fight_started.emit(fight);
+}
+
 void Game::center_view_on_city()
 {
     const Player* p = Playerlist::getInstance()->getActiveplayer();
