@@ -25,6 +25,7 @@
 #include "callback-enums.h"
 #include "army.h"
 #include "fight.h"
+#include "game-parameters.h"
 
 class NextTurn;
 class GameBigMap;
@@ -87,8 +88,11 @@ class Game
 	can_center_selected_stack,
 	can_defend_selected_stack,
 	can_search_selected_stack,
+	can_inspect_selected_stack,
 	can_move_selected_stack,
 	can_move_all_stacks,
+	can_disband_stack,
+	can_change_signpost,
 	can_end_turn;
     sigc::signal<void, Stack *> stack_info_changed;
     sigc::signal<void, Glib::ustring, MapTipPosition> map_tip_changed;
@@ -113,6 +117,7 @@ class Game
     sigc::signal<void, Player *> game_over;
     sigc::signal<void, Player *> player_died;
     
+
  private:
 
     /**
@@ -160,6 +165,9 @@ class Game
     void stackUpdate(Stack* s);
     //! Called whenever a stack has died; updates bigmap as well
     void stackDied(Stack* s);
+    //! Called whenever players fight
+    void on_fight_started(Fight &fight);
+
 
     
     void looting_city(City *city, int &gold);
@@ -173,6 +181,7 @@ class Game
     std::vector<Hero*> d_herotemplates[MAX_PLAYERS];
 
     bool input_locked;
+
 };
 
 #endif
