@@ -60,7 +60,19 @@ GamePreferencesDialog::GamePreferencesDialog()
     xml->get_widget("ruins_scale", ruins_scale);
     xml->get_widget("temples_scale", temples_scale);
     xml->get_widget("map_size_combobox", map_size_combobox);
+    xml->get_widget("view_enemies_checkbutton", view_enemies_checkbutton);
+    xml->get_widget("view_production_checkbutton", view_production_checkbutton);
+    xml->get_widget("quests_checkbutton", quests_checkbutton);
+    xml->get_widget("hidden_map_checkbutton", hidden_map_checkbutton);
+    xml->get_widget("neutral_combobox", neutral_cities_combobox);
+    xml->get_widget("diplomacy_checkbutton", diplomacy_checkbutton);
+    xml->get_widget("military_advisor_checkbutton", 
+                    military_advisor_checkbutton);
+    xml->get_widget("quick_start_checkbutton", quick_start_checkbutton);
+    xml->get_widget("intense_combat_checkbutton", intense_combat_checkbutton);
+    xml->get_widget("random_turns_checkbutton", random_turns_checkbutton);
 
+    neutral_cities_combobox->set_active(GameParameters::AVERAGE);
     process_armies_combobox->set_active(
 	GameParameters::PROCESS_ARMIES_AT_PLAYERS_TURN);
 
@@ -324,6 +336,20 @@ void GamePreferencesDialog::on_start_game_clicked()
     g.process_armies = GameParameters::ProcessArmies(
 	process_armies_combobox->get_active_row_number());
 
+    g.see_opponents_stacks = view_enemies_checkbutton->get_active();
+    g.see_opponents_production = view_production_checkbutton->get_active();
+    g.play_with_quests = quests_checkbutton->get_active();
+    g.hidden_map = hidden_map_checkbutton->get_active();
+
+    g.neutral_cities = GameParameters::NeutralCities (
+	neutral_cities_combobox->get_active_row_number());
+
+    g.diplomacy = diplomacy_checkbutton->get_active();
+    g.random_turns = random_turns_checkbutton->get_active();
+    g.quick_start = quick_start_checkbutton->get_active();
+    g.intense_combat = intense_combat_checkbutton->get_active();
+    g.military_advisor = military_advisor_checkbutton->get_active();
+
     // and call callback
     game_started(g);
 }
