@@ -60,6 +60,7 @@
 #include "quest-assigned-dialog.h"
 #include "quest-completed-dialog.h"
 #include "preferences-dialog.h"
+#include "fight-order-dialog.h"
 
 #include "../ucompose.hpp"
 #include "../defs.h"
@@ -73,6 +74,7 @@
 #include "../ruin.h"
 #include "../player.h"
 #include "../stacklist.h"
+#include "../signpostlist.h"
 #include "../playerlist.h"
 #include "../hero.h"
 #include "../temple.h"
@@ -204,6 +206,18 @@ GameWindow::GameWindow()
     xml->get_widget("fullscreen_menuitem", fullscreen_menuitem);
     xml->connect_clicked("preferences_menuitem", 
 			 sigc::mem_fun(*this, &GameWindow::on_preferences_activated));
+
+    xml->get_widget("end_turn_menuitem", end_turn_menuitem);
+    xml->get_widget("move_all_menuitem", move_all_menuitem);
+    xml->get_widget("disband_menuitem", disband_menuitem);
+    xml->get_widget("signpost_menuitem", signpost_menuitem);
+    xml->get_widget("search_menuitem", search_menuitem);
+    xml->get_widget("inspect_menuitem", inspect_menuitem);
+
+    xml->connect_clicked("fight_order_menuitem",
+			 sigc::mem_fun(*this, &GameWindow::on_fight_order_activated));
+    xml->connect_clicked("resign_menuitem",
+			 sigc::mem_fun(*this, &GameWindow::on_resign_activated));
 }
 
 GameWindow::~GameWindow()
@@ -331,7 +345,7 @@ create_and_dump_scenario(const std::string &file, const GameParameters &g)
     std::string path = File::getSavePath();
     path += file;
     
-    creator.create();
+    creator.create(g);
     creator.dump(path);
     
     return path;
@@ -357,7 +371,8 @@ void GameWindow::load_game(std::string file_path)
 
 namespace 
 {
-    // helper for connecting control panel buttons
+    // helpers for connecting control panel buttons and corresponding
+    // menu items.
     void setup_button(Gtk::Button *button,
 		      sigc::slot<void> slot,
 		      sigc::signal<void, bool> &game_signal)
@@ -365,6 +380,13 @@ namespace
 	button->signal_clicked().connect(slot);
 	game_signal.connect(sigc::mem_fun(button, &Gtk::Widget::set_sensitive));
     }
+    void setup_menuitem(Gtk::MenuItem *item,
+		      sigc::slot<void> slot,
+		      sigc::signal<void, bool> &game_signal)
+    {
+	item->signal_activate().connect(slot);
+	game_signal.connect(sigc::mem_fun(item, &Gtk::Widget::set_sensitive));
+    }
 }
 
 void GameWindow::setup_game(std::string file_path)
@@ -408,9 +430,27 @@ void GameWindow::setup_game(std::string file_path)
     setup_button(move_all_button,
 		 sigc::mem_fun(game.get(), &Game::move_all_stacks),
 		 game->can_move_all_stacks);
+    setup_menuitem(move_all_menuitem,
+		   sigc::mem_fun(game.get(), &Game::move_all_stacks),
+		   game->can_move_all_stacks);
     setup_button(end_turn_button,
 		 sigc::mem_fun(game.get(), &Game::end_turn),
 		 game->can_end_turn);
+    setup_menuitem(end_turn_menuitem,
+		   sigc::mem_fun(game.get(), &Game::end_turn),
+		   game->can_end_turn);
+    setup_menuitem(disband_menuitem,
+	           sigc::mem_fun(*this, &GameWindow::on_disband_activated),
+		   game->can_disband_stack);
+    setup_menuitem(signpost_menuitem,
+	           sigc::mem_fun(*this, &GameWindow::on_signpost_activated),
+		   game->can_change_signpost);
+    setup_menuitem(search_menuitem,
+		   sigc::mem_fun(game.get(), &Game::search_selected_stack),
+		   game->can_search_selected_stack);
+    setup_menuitem(inspect_menuitem,
+	           sigc::mem_fun(*this, &GameWindow::on_inspect_activated),
+		   game->can_inspect_selected_stack);
 
     // setup game callbacks
     game->sidebar_stats_changed.connect(
@@ -726,6 +766,95 @@ void GameWindow::on_fullscreen_activated()
 	window->unfullscreen();
 }
 
+void GameWindow::on_signpost_activated()
+{
+    std::auto_ptr<Gtk::Dialog> dialog;
+    
+    Glib::RefPtr<Gnome::Glade::Xml> xml
+	= Gnome::Glade::Xml::create(get_glade_path() + "/signpost-change-dialog.glade");
+	
+    Gtk::Dialog *d;
+    xml->get_widget("dialog", d);
+    dialog.reset(d);
+    dialog->set_transient_for(*window.get());
+    
+    dialog->set_title(_("Signpost"));
+
+    Stack *stack = Playerlist::getActiveplayer()->getActivestack();
+    if (!stack)
+      return;
+    Signpost *s = Signpostlist::getInstance()->getObjectAt(stack->getPos());
+    if (!s)
+      return;
+    Gtk::Label *l;
+    xml->get_widget("label", l);
+    l->set_text(_("Change the message on this sign:"));
+    Gtk::Entry *e;
+    xml->get_widget("message_entry", e);
+    e->set_text(s->getName());
+    dialog->show_all();
+    int response = dialog->run();
+
+    if (response == 0)
+      Playerlist::getActiveplayer()->signpostChange(s, e->get_text());
+
+  return;
+}
+
+void GameWindow::on_disband_activated()
+{
+    std::auto_ptr<Gtk::Dialog> dialog;
+    
+    Glib::RefPtr<Gnome::Glade::Xml> xml
+	= Gnome::Glade::Xml::create(get_glade_path() + "/disband-stack-dialog.glade");
+	
+    Gtk::Dialog *d;
+    xml->get_widget("dialog", d);
+    dialog.reset(d);
+    dialog->set_transient_for(*window.get());
+    
+    dialog->set_title(_("Disband"));
+
+    Gtk::Label *l;
+    xml->get_widget("label", l);
+
+    l->set_text(_("Are you sure you want to disband this group?"));
+    dialog->show_all();
+    int response = dialog->run();
+
+  if (response == 0) //disband the active stack
+    Playerlist::getActiveplayer()->stackDisband(NULL);
+
+  return;
+}
+
+void GameWindow::on_resign_activated()
+{
+    std::auto_ptr<Gtk::Dialog> dialog;
+    
+    Glib::RefPtr<Gnome::Glade::Xml> xml
+	= Gnome::Glade::Xml::create(get_glade_path() + "/player-resign-dialog.glade");
+	
+    Gtk::Dialog *d;
+    xml->get_widget("dialog", d);
+    dialog.reset(d);
+    dialog->set_transient_for(*window.get());
+    
+    dialog->set_title(_("Resign"));
+
+    Gtk::Label *l;
+    xml->get_widget("label", l);
+
+    l->set_text(_("Are you sure you want to resign?"));
+    dialog->show_all();
+    int response = dialog->run();
+
+  if (response == 0) //disband all stacks, raze all cities
+    Playerlist::getActiveplayer()->resign();
+
+  return;
+}
+
 void GameWindow::on_preferences_activated()
 {
     PreferencesDialog d;
@@ -733,6 +862,13 @@ void GameWindow::on_preferences_activated()
     d.run();
 }
 
+void GameWindow::on_fight_order_activated()
+{
+    FightOrderDialog d(Playerlist::getActiveplayer());
+    d.set_parent_window(*window.get());
+    d.run();
+}
+
 void GameWindow::stop_game()
 {
     Sound::getInstance()->disableBackground();
@@ -1267,13 +1403,16 @@ bool GameWindow::on_temple_visited(bool hasHero, Temple *temple, int blessCount)
     l->set_text(s);
     s = l->get_text() + "\n" + _("Seek more blessings in far temples!");
     l->set_text(s);
-    if (hasHero)
-      s = l->get_text() + "\n\n" + _("Do you seek a quest?");
-    l->set_text(s);
+    if (GameScenario::s_play_with_quests == true)
+      {
+        if (hasHero)
+          s = l->get_text() + "\n\n" + _("Do you seek a quest?");
+        l->set_text(s);
+      }
 
     dialog->show_all();
 
-    if (hasHero == false)
+    if (hasHero == false || GameScenario::s_play_with_quests == false)
       {
         close_button->hide();
         s = _("_Close");
@@ -1282,7 +1421,7 @@ bool GameWindow::on_temple_visited(bool hasHero, Temple *temple, int blessCount)
 
     int response = dialog->run();
 
-    if (hasHero == false)
+    if (hasHero == false || GameScenario::s_play_with_quests == false)
       response = 1;
 
     if (response == 0)		// accepted a quest
@@ -1826,3 +1965,11 @@ void GameWindow::on_quest_expired(Quest *quest)
     dialog->show_all();
     dialog->run();
 }
+
+void GameWindow::on_inspect_activated ()
+{
+  HeroDialog d(dynamic_cast<Hero*>(currently_selected_stack->getFirstHero()), 
+               currently_selected_stack->getPos());
+  d.set_parent_window(*window.get());
+  d.run();
+}
