@@ -92,6 +92,12 @@ class GameWindow: public sigc::trackable
     Gtk::Container *sdl_container;
     Gtk::Widget *sdl_widget;
     Gtk::CheckMenuItem *fullscreen_menuitem;
+    Gtk::MenuItem *end_turn_menuitem;
+    Gtk::MenuItem *move_all_menuitem;
+    Gtk::MenuItem *search_menuitem;
+    Gtk::MenuItem *inspect_menuitem;
+    Gtk::MenuItem *disband_menuitem;
+    Gtk::MenuItem *signpost_menuitem;
     Gtk::Box *stack_info_box;
     Gtk::Box *stack_info_container;
     Gtk::Label *group_moves_label;
@@ -149,10 +155,16 @@ class GameWindow: public sigc::trackable
     void on_cities_activated();
     void on_gold_activated();
     void on_quests_activated();
+    void on_disband_activated();
+    void on_resign_activated();
+    void on_signpost_activated();
+    void on_inspect_activated();
 
     void on_fullscreen_activated();
     void on_preferences_activated();
     
+    void on_fight_order_activated();
+
     void on_message_requested(std::string msg);
     void on_stack_selected_in_report(Stack *stack);
     void on_city_selected_in_report(City *city);
