@@ -29,6 +29,7 @@
 #include "GameMap.h"
 #include "sdl-draw.h"
 #include "GraphicsCache.h"
+#include "FogMap.h"
 
 OverviewMap::OverviewMap()
 {
@@ -80,10 +81,12 @@ bool OverviewMap::isShadowed(Uint32 type, int i, int j)
 
   return false;
 }
+
 void OverviewMap::draw_tile_pixel(Maptile *t, int i, int j)
 {
   SDL_Color c = t->getColor();
   Tile::Pattern p = t->getPattern();
+  
   Uint32 first = SDL_MapRGB(static_surface->format, c.r, c.g, c.b);
   switch (p)
     {
@@ -228,6 +231,15 @@ void OverviewMap::redraw_tiles(Rectangle tiles)
     draw();
 }
 
+bool OverviewMap::isFogged(Vector <int> pos)
+{
+  //is this tile visible, or not?
+  FogMap *fogmap = Playerlist::getActiveplayer()->getFogMap();
+  if (fogmap->getFogTile(pos) == FogMap::CLOSED)
+    return true;
+  return false;
+}
+
 void OverviewMap::draw_terrain_pixels(Rectangle r)
 {
     GameMap *gm = GameMap::getInstance();
@@ -239,9 +251,10 @@ void OverviewMap::draw_terrain_pixels(Rectangle r)
         {
             int x = int(i / pixels_per_tile);
             int y = int(j / pixels_per_tile);
+
 	    if (gm->getTile(x,y)->getBuilding() == Maptile::ROAD ||
-                gm->getTile(x,y)->getBuilding() == Maptile::BRIDGE)
-		draw_pixel(static_surface, i, j, road_color);
+                     gm->getTile(x,y)->getBuilding() == Maptile::BRIDGE)
+		         draw_pixel(static_surface, i, j, road_color);
 	    else
 	    {
                 draw_tile_pixel (GameMap::getInstance()->getTile(x,y), i, j);
@@ -275,6 +288,10 @@ void OverviewMap::draw_stacks()
             if (mytile->getBuilding() == Maptile::CITY)
                 continue;
 
+            // don't draw stacks on tiles we can't see
+            if (isFogged (pos) == true)
+                continue;
+
             pos = mapToSurface(pos);
             draw_hline(surface, pos.x - size, pos.x + size, pos.y, outline);
             draw_vline(surface, pos.x, pos.y - size, pos.y + size, outline);
@@ -290,6 +307,7 @@ void OverviewMap::after_draw()
 
 void OverviewMap::draw()
 {
+    Uint32 fog_color = SDL_MapRGB(surface->format, 0, 0, 0);
     Playerlist *pl = Playerlist::getInstance();
     int size = int(pixels_per_tile) > 1 ? int(pixels_per_tile) : 1;
     assert(surface);
@@ -308,6 +326,8 @@ void OverviewMap::draw()
     {
         if (it->isHidden() == true && it->getOwner() != pl->getActiveplayer())
           continue;
+        if (it->isFogged())
+          continue;
         Vector<int> pos = it->getPos();
         pos = mapToSurface(pos);
 
@@ -322,6 +342,8 @@ void OverviewMap::draw()
     for (Templelist::iterator it = Templelist::getInstance()->begin();
         it != Templelist::getInstance()->end(); it++)
     {
+        if (it->isFogged())
+          continue;
         Vector<int> pos = it->getPos();
         pos = mapToSurface(pos);
 	Uint32 raw;
@@ -331,6 +353,21 @@ void OverviewMap::draw()
 			 pos.x + size, pos.y + size, raw);
     }
 
+    //fog it up
+    for (int i = 0; i < GameMap::getWidth(); i++)
+        for (int j = 0; j < GameMap::getHeight(); j++)
+        {
+          Vector <int> pos;
+          pos.x = i;
+          pos.y = j;
+          if (isFogged(pos) == true)
+            {
+              pos = mapToSurface(pos);
+              draw_filled_rect(surface, pos.x, pos.y,
+                               pos.x + size, pos.y + size, fog_color);
+            }
+        }
+
     // let derived classes do their job
     after_draw();
 }
@@ -382,6 +419,8 @@ void OverviewMap::draw_cities (bool all_razed)
       it != Citylist::getInstance()->end(); it++)
   {
       SDL_Surface *tmp;
+      if (it->isFogged())
+        continue;
       if (it->isBurnt() == true || all_razed == true)
         tmp = gc->getSmallRuinedCityPic();
       else
