@@ -41,6 +41,8 @@ class MoveResult;
 class FogMap;
 class Fight;
 class Reward;
+class FogMap;
+class Signpost;
 
 /** The abstract player class.
   *
@@ -226,6 +228,9 @@ class Player: public sigc::trackable
         //! get the fight order of the player
 	std::list<Uint32> getFightOrder() const {return d_fight_order;}
 
+        //! set the fight order of the player
+	virtual void setFightOrder(std::list<Uint32> order)=0;
+
         //! Dumps the items in the actionlist on stderr
         void dumpActionlist() const;
 
@@ -429,6 +434,25 @@ class Player: public sigc::trackable
           */
         virtual bool giveReward (Stack *stack, Reward *reward) = 0;
 
+        //! Disband a player's stack
+        virtual bool stackDisband(Stack* s) =0;
+
+        //! Disband all the player's stacks and raze all cities.
+        virtual void resign() =0;
+
+        //! Change the text on the signpost of the square we're sitting on
+        virtual bool signpostChange(Signpost * s, std::string message) =0;
+
+        //! Rename a city
+        virtual bool cityRename(City *c, std::string name) =0;
+
+        /** Vector new units from a player's city to a destination.
+            @return always returns true
+            @param  city   the city to vector from
+            @param  dest   the place on the map to vector to
+          */
+        virtual bool vectorFromCity(City* c, Vector<int> dest) = 0;
+
         /** Signal raised when a city is conquered. This signal is solely
           * for internal use. Don't use it, you may break stability (Background:
           * libsigc++ doesn't guarantee order of execution and this signal may
