@@ -35,6 +35,9 @@
 #include "FogMap.h"
 #include "xmlhelper.h"
 #include "ruinlist.h"
+#include "GameScenario.h"
+#include "game-parameters.h"
+#include "signpost.h"
 
 using namespace std;
 
@@ -194,6 +197,42 @@ bool RealPlayer::stackJoin(Stack* receiver, Stack* joining, bool grouped)
 }
 
 
+bool RealPlayer::signpostChange(Signpost *s, std::string message)
+{
+  if (!s)
+    return false;
+  s->setName(message);
+  Action_ModifySignpost* item = new Action_ModifySignpost();
+  item->fillData(s, message);
+  d_actions.push_back(item);
+  return true;
+}
+
+bool RealPlayer::cityRename(City *c, std::string name)
+{
+  if (!c)
+    return false;
+  c->setName(name);
+  Action_RenameCity* item = new Action_RenameCity();
+  item->fillData(c, name);
+  d_actions.push_back(item);
+  return true;
+}
+
+bool RealPlayer::stackDisband(Stack* s)
+{
+    debug("player::stackDisband(Stack*)")
+    if (!s)
+      s = getActivestack();
+    getStacklist()->setActivestack(0);
+    Action_Disband* item = new Action_Disband();
+    item->fillData(s);
+    d_actions.push_back(item);
+    sdyingStack.emit(s);
+    s->getPlayer()->getStacklist()->deleteStack(s);
+    return true;
+}
+
 bool RealPlayer::stackMove(Stack* s)
 {
     debug("player::stackMove(Stack*)")
@@ -284,6 +323,32 @@ MoveResult *RealPlayer::stackMove(Stack* s, Vector<int> dest, bool follow)
                 // stack has survived. Subtract some MP because fighting takes
                 // time.
                 s->decrementMoves(2);
+                //if this is a neutral city, and we're playing with 
+                //active neutral cities, AND it hasn't already been attacked
+                //then it's production gets turned on
+                Player *neu = city->getPlayer(); //neutral player
+                if (GameScenario::s_neutral_cities == GameParameters::ACTIVE &&
+                    neu == Playerlist::getInstance()->getNeutral() &&
+                    city->getProductionIndex() == -1)
+                {
+                  //great, then let's turn on the production.
+                  //well, we already made a unit, and we want to produce more
+                  //of it.
+                  Stack *o = neu->getStacklist()->getObjectAt(city->getPos());
+                  if (o)
+                    {
+                      int army_type = o->getStrongestArmy()->getType();
+                      for (int i = 0; i < 4; i++)
+                        {
+                          if (city->getArmytype(i) == army_type)
+                            {
+                              // hey, we found the droid we were looking for
+                              city->setProduction(i);
+                              break;
+                            }
+                        }
+                    }
+                }
             }
             moveResult->setStepCount(stepCount);
             supdatingStack.emit(0);
@@ -1250,4 +1315,42 @@ bool RealPlayer::stackMoveOneStep(Stack* s)
     return true;
 }
 
+bool RealPlayer::vectorFromCity(City * c, Vector<int> dest)
+{
+  c->setVectoring(dest);
+  Action_Vector* item = new Action_Vector();
+  item->fillData(c, dest);
+  d_actions.push_back(item);
+  return true;
+}
+
+void RealPlayer::setFightOrder(std::list<Uint32> order) 
+{
+  d_fight_order = order;
+  Action_FightOrder * item = new Action_FightOrder();
+  item->fillData(order);
+  d_actions.push_back(item);
+}
+
+void RealPlayer::resign() 
+{
+  //disband all stacks
+  getStacklist()->flClear();
+
+  //raze all cities
+  Citylist *cl = Citylist::getInstance();
+  for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
+    {
+      if ((*it).getPlayer() == this)
+        (*it).setBurnt(true);
+    }
+
+  Action_Resign* item = new Action_Resign();
+  item->fillData();
+  d_actions.push_back(item);
+    
+  getStacklist()->setActivestack(0);
+  supdatingStack.emit(0);
+}
+
 // End of file
