@@ -52,6 +52,12 @@ class RealPlayer : public Player
 
         bool stackSplit(Stack* s);
         bool stackJoin(Stack* receiver, Stack* joining, bool grouped);
+        bool stackDisband(Stack* s);
+        bool signpostChange(Signpost *s, std::string message);
+        bool cityRename(City *c, std::string name);
+        bool vectorFromCity(City* c, Vector<int> dest);
+	void setFightOrder(std::list<Uint32> order);
+        void resign();
 
         bool stackMove(Stack* s);
         MoveResult *stackMove(Stack* s, Vector<int> dest, bool follow);
