@@ -19,7 +19,8 @@
 #include "citylist.h"
 #include "playerlist.h"
 #include "GraphicsCache.h"
-#include "gamebigmap.h" //remove me
+#include "game.h" //remove me
+#include "GameScenario.h"
 
 VectorMap::VectorMap(City *c, enum ShowVectoring v)
 {
@@ -35,6 +36,8 @@ VectorMap::VectorMap(City *c)
 }
 void VectorMap::draw_city (City *c, Uint32 &type, bool &prod)
 {
+  if (c->isFogged())
+    return;
   GraphicsCache *gc = GraphicsCache::getInstance();
   SDL_Surface *tmp;
   if (c->isBurnt() == true || (type == 3 && prod == false))
@@ -88,6 +91,7 @@ void VectorMap::draw_cities (std::list<City*> citylist, Uint32 type)
       draw_city ((*it), type, prod);
     }
 }
+
 void VectorMap::draw_lines (std::list<City*> citylist)
 {
   Citylist *cl = Citylist::getInstance();
@@ -96,6 +100,8 @@ void VectorMap::draw_lines (std::list<City*> citylist)
   std::list<City*>::iterator it;
   for (it = citylist.begin(); it != citylist.end(); it++)
     {
+      if ((*it)->isFogged() == true)
+        continue;
       start = (*it)->getPos();
       end = cl->getObjectAt((*it)->getVectoring())->getPos();
 
@@ -199,6 +205,8 @@ void VectorMap::after_draw()
         // draw lines from origination to city
         for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
           {
+            if ((*it).isFogged() == true)
+              continue;
             if ((*it).getPlayer() == city->getPlayer())
               {
                 //is this a city that is vectoring to me?
@@ -255,10 +263,10 @@ void VectorMap::mouse_button_event(MouseButtonEvent e)
       Vector<int> dest;
       dest = mapFromScreen(e.pos);
 
-      if (GameBigMap::see_opponents_production == true)
-        nearestCity = cl->getNearestCity(dest, 4);
+      if (GameScenario::s_see_opponents_production == true)
+        nearestCity = cl->getNearestVisibleCity(dest, 4);
       else
-        nearestCity = cl->getNearestFriendlyCity(dest, 4);
+        nearestCity = cl->getNearestVisibleFriendlyCity(dest, 4);
       if (nearestCity == NULL)
         return;
 
@@ -273,14 +281,14 @@ void VectorMap::mouse_button_event(MouseButtonEvent e)
             if (dest != city->getVectoring())
               {
 	        destination_chosen.emit(dest);
-	        city->setVectoring(nearestCity->getPos());
+                Playerlist::getActiveplayer()->vectorFromCity(city, dest);
 		setClickAction(CLICK_SELECTS);
 	        draw();
               }
             else if (dest == Vector<int>(-1, -1)) //stop vectoring
               {
 	        destination_chosen.emit(dest);
-	        city->setVectoring(dest);
+                Playerlist::getActiveplayer()->vectorFromCity(city, dest);
 		setClickAction(CLICK_SELECTS);
 	        draw();
               }
